@@ -20,10 +20,18 @@ K = 10 ** 3
 M = 10 ** 6
 G = 10 ** 9
 
+DEVICE_CONFIG["PlutoSDR"] = {
+    "center_freq": dev_range(start=325 * M, stop=3.8 * G, step=1),
+    "sample_rate": dev_range(start=2.1 * M, stop=61.44 * M, step=1),
+    "bandwidth": dev_range(start=0.2 * M, stop=56 * M, step=1),
+    "tx_rf_gain": list(range(-89, 1)),
+    "rx_rf_gain": list(range(-3, 72)),
+}
+
 # http://www.nuand.com/bladeRF-brief.pdf
 DEVICE_CONFIG["BladeRF"] = {
     "center_freq": dev_range(start=300 * M, stop=3.8 * G, step=1),
-    "sample_rate": dev_range(start=1.5 * M, stop=40 * M, step=1),
+    "sample_rate": dev_range(start=2.5 * M, stop=40 * M, step=1),
     "bandwidth": dev_range(start=1.5 * M, stop=28 * M, step=1),
     "rx_channel": ["RX1", "RX2"],
     "tx_channel": ["TX1", "TX2"],
